---
title: <span class="badge object-type-enum"></span> MovingAverageModel
---
# <span class="badge object-type-enum"></span> MovingAverageModel

## Definition

```python
class MovingAverageModel(enum.StrEnum):
    SIMPLE = "simple"
    LINEAR = "linear"
    EWMA = "ewma"
    HOLT = "holt"
    HOLT_WINTERS = "holt_winters"
```
